@@ -32,7 +32,7 @@
 << "CREATE TABLE settings ("
 	"key_ CHAR(20) UNIQUE, "        // mySql does not like 'key' or 'option"
 	"value " B64_BLOB ")"
-<< "INSERT INTO settings (key_, value) VALUES ('schema', '" SCHEMA_VERSION "')"
+<< "INSERT INTO settings (key_, value) VALUES ('schema', '" INITIAL_SCHEMA_VERSION "')"
 
 /*
  * All items (keys, tokens, requests, certs, crls, templates)
@@ -305,6 +305,16 @@
 << "UPDATE settings SET value='7' WHERE key_='schema'"
 	;
 
+	schemas[7]
+// OpenVPN TA (tls-auth) keys associated to the CA to be
+// the same for all issued certificates
+<< "CREATE TABLE takeys ("
+	"item INTEGER UNIQUE, "        // reference to items(id) of the CA
+	"value " B64_BLOB ", "         // The base64 encoded 2048 bit key
+	"FOREIGN KEY (item) REFERENCES items (id))"
+<< "UPDATE settings SET value='8' WHERE key_='schema'"
+	;
+
 /* When adding new tables or views, also add them to the list
  * in XSqlQuery::rewriteQuery(QString) in lib/sql.cpp
  */
