@@ -563,14 +563,19 @@ int db_x509::exportFlags(const QModelIndex &idx) const
 	if (!crt->isCA())
 		disable_flags |= F_CA;
 
+	pki_key *key = crt->getPubKey();
+	if (key && key->getKeyType() != EVP_PKEY_RSA && key->getJWKcrv().isEmpty())
+		disable_flags |= F_JWK;
+	delete key;
+
 	return disable_flags;
 }
 
-void db_x509::writeTaggedPEM(BioByteArray &b, const QString &tag, XFile &file)
+void db_x509::writeTaggedPEM(const BioByteArray &b, const QString &tag, XFile &file)
 {
 	if (b.size() > 0) {
 		file.write(QString("<%1>\n").arg(tag).toLatin1());
-		file.write(b);
+		file.write(b.byteArray());
 		file.write(QString("</%1>\n").arg(tag).toLatin1());
 	}
 }
@@ -591,31 +596,17 @@ void db_x509::exportItems(const QModelIndexList &list,
 	}
 
 	if (xport->match_all(F_PEM)) {
-		if (xport->match_all(F_OVPN)) {
-			BioByteArray key, cert, extra, ca;
-			pki_evp *pkey = (pki_evp *)crt->getRefKey();
-			if (pkey)
-				pkey->pem(key, pki_export::by_id(20)); // PEM unencrypted
-			for (; crt && crt != oldcrt; oldcrt = crt, crt = crt->getSigner())
-			{
-				if (crt == crt->getSigner())
-					crt->pem(ca);
-				else if (cert.size() == 0)
-					crt->pem(cert);
-				else
-					crt->pem(extra);
-			}
-			writeTaggedPEM(ca, "ca", file);
-			writeTaggedPEM(extra, "extra-certs", file);
-			writeTaggedPEM(cert, "cert", file);
-			writeTaggedPEM(key, "key", file);
-		} else if (xport->match_all(F_CHAIN)) {
+		if (xport->match_all(F_CHAIN)) {
 			for (; crt && crt != oldcrt; oldcrt = crt, crt = crt->getSigner())
 				crt->writeCert(file, true);
 		} else if (xport->match_all(F_UNREVOKED)) {
 			foreach(pki_x509 *pki, Store.getAll<pki_x509>())
 				if (!pki->isRevoked())
 					pki->writeCert(file, true);
+		} else if (xport->match_all(F_UNUSABLE)) {
+			foreach(pki_x509 *pki, Store.getAll<pki_x509>())
+				if (pki->unusable())
+					pki->writeCert(file, true);
 		} else if (xport->match_all(F_ALL)) {
 			foreach(pki_x509 *pki, Store.getAll<pki_x509>())
 				pki->writeCert(file, true);
@@ -629,7 +620,7 @@ void db_x509::exportItems(const QModelIndexList &list,
 					throw errorEx(tr("Not possible for a token key: '%1'").
 							arg(crt->getIntName()));
 				if (xport->match_all(F_PKCS8)) {
-					pkey->writePKCS8(file, EVP_des_ede3_cbc(),
+					pkey->writePKCS8(file, EVP_aes_256_cbc(),
 						PwDialogCore::pwCallback, true);
 				} else {
 					pkey->writeKey(file, NULL, NULL, true);
@@ -638,21 +629,57 @@ void db_x509::exportItems(const QModelIndexList &list,
 			foreach(crt, certs)
 				crt->writeCert(file, true);
 		}
-	} else if (xport->match_all(F_DER)) {
-		crt->writeCert(file, false);
+	} else if (xport->match_all(F_OVPN)) {
+		BioByteArray key, cert, extra, ca;
+		pki_evp *pkey = (pki_evp *)crt->getRefKey();
+		if (pkey)
+			pkey->pem(key, pki_export::by_id(20)); // PEM unencrypted
+		for (; crt && crt != oldcrt; oldcrt = crt, crt = crt->getSigner())
+		{
+			if (crt == crt->getSigner())
+				crt->pem(ca);
+			else if (cert.size() == 0)
+				crt->pem(cert);
+			else
+				crt->pem(extra);
+		}
+		writeTaggedPEM(ca, "ca", file);
+		writeTaggedPEM(extra, "extra-certs", file);
+		writeTaggedPEM(cert, "cert", file);
+		writeTaggedPEM(key, "key", file);
+		writeTaggedPEM(crt->getTaKey().toLatin1(), "tls-auth", file);
 	} else if (xport->match_all(F_PKCS7)) {
 		writePKCS7(crt, file, xport->flags, list);
-	} else if (xport->match_all(F_PKCS12)) {
-		writePKCS12(crt, file, xport->match_all(F_CHAIN));
 	} else if (xport->match_all(F_INDEX)) {
 		writeIndex(file, certs);
 	} else if (xport->match_all(F_CAL)) {
 		QStringList vcal;
 		foreach(crt, certs) {
-			vcal += xport->match_all(F_CHAIN) ?
+			vcal += xport->match_all(F_CA) ?
 				crt->icsVEVENT_ca() : crt->icsVEVENT();
 		}
 		writeVcalendar(file, vcal);
+	} else if (xport->match_all(F_TAKEY)) {
+		file.write(crt->getTaKey().toLatin1());
+	} else {
+		qDebug() << "exportItems: db_base";
+		db_base::exportItems(list, xport, file);
+	}
+}
+
+void db_x509::exportItem(const QModelIndex &index,
+			const pki_export *xport, XFile &file) const
+{
+	pki_x509 *crt = fromIndex<pki_x509>(index);
+
+	if (xport->match_all(F_DER)) {
+		crt->writeCert(file, false);
+	} else if (xport->match_all(F_PKCS12)) {
+		writePKCS12(crt, file, xport->match_all(F_CHAIN));
+	} else if (xport->match_all(F_CONFIG)) {
+		crt->opensslConf(file);
+	} else {
+		db_base::exportItem(index, xport, file);
 	}
 }
 
@@ -714,6 +741,11 @@ void db_x509::writePKCS7(pki_x509 *cert, XFile &file, int flags,
 				if ((flags & F_ALL) || !cer->isRevoked())
 					p7->append_item(cer);
 			}
+		} else if (flags & F_UNUSABLE) {
+			foreach(pki_x509 *cer, Store.getAll<pki_x509>()) {
+				if (cer->unusable())
+					p7->append_item(cer);
+			}
 		} else if (flags) {
 			foreach(QModelIndex idx, list) {
 				cert = fromIndex<pki_x509>(idx);
