@@ -9,12 +9,12 @@
 #define __PKI_KEY_H
 
 #include <QString>
+#include <QJsonObject>
 #include <openssl/rsa.h>
 #include <openssl/bn.h>
 #include <openssl/pem.h>
 #include <openssl/evp.h>
 #include "pki_base.h"
-//#include "pki_export.h"
 #include "builtin_curves.h"
 
 #define PEM_STRING_OPENSSH_KEY "OPENSSH PRIVATE KEY"
@@ -61,7 +61,11 @@ class keytype
 	}
 	QString traditionalPemName() const
 	{
-		return name + " PRIVATE KEY";
+		return
+#ifdef EVP_PKEY_ED25519
+			type == EVP_PKEY_ED25519 ? QString("PRIVATE KEY") :
+#endif
+				QString("%1 PRIVATE KEY").arg(name);
 	}
 	static const keytype byType(int type)
 	{
@@ -177,7 +181,6 @@ class pki_key: public pki_base
 		bool isPub;
 		EVP_PKEY *key;
 		QString BN2QString(const BIGNUM *bn) const;
-		QString BNoneLine(BIGNUM *bn) const;
 		QByteArray SSH2publicQByteArray(bool raw=false) const;
 		QByteArray X509_PUBKEY_public_key() const;
 		QByteArray PEM_comment() const;
@@ -189,8 +192,10 @@ class pki_key: public pki_base
 		void ssh_key_QBA2data(const QByteArray &ba,
 					QByteArray *data) const;
 		void ssh_key_bn2data(const BIGNUM *bn, QByteArray *data) const;
+
 	private:
 		mutable int useCount; // usage counter
+
 	public:
 
 		pki_key(const QString &name = QString());
@@ -205,9 +210,11 @@ class pki_key: public pki_base
 		virtual bool isToken();
 		virtual QString getTypeString(void) const;
 		virtual QList<int> possibleHashNids();
-		QString getMsg(msg_type msg) const;
+		QString getMsg(msg_type msg, int n = 1) const;
 
 		void writePublic(XFile &file, bool pem) const;
+		QString getJWKcrv() const;
+		void fillJWK(QJsonObject &json, const pki_export *xport) const;
 		bool compare(const pki_base *ref) const;
 		int getKeyType() const;
 		bool isPrivKey() const;
@@ -253,11 +260,8 @@ class pki_key: public pki_base
 		QByteArray i2d() const;
 		EVP_PKEY *load_ssh2_key(const QByteArray &ba);
 		void writeSSH2public(XFile &file) const;
-		void writeSSH2private(XFile &file, pem_password_cb *cb) const;
 		QString fingerprint(const QString &format) const;
 		bool SSH2_compatible() const;
-		void write_SSH2_ed25519_private(BIO *b,
-			const EVP_PKEY *pkey, const EVP_CIPHER *enc) const;
 		void print(BioByteArray &b, enum print_opt opt) const;
 		void resetUcount()
 		{
