@@ -103,7 +103,6 @@ pki_pkcs12::pki_pkcs12(const QString &fname)
 	}
 	if (mykey) {
 		key = new pki_evp(mykey);
-		Q_CHECK_PTR(key);
 		key->setIntName(alias + "_key");
 		key->pkiSource = imported;
 		inheritFilename(key);
@@ -133,12 +132,15 @@ void pki_pkcs12::writePKCS12(XFile &file, encAlgo &encAlgo) const
 {
 	Passwd pass;
 	PKCS12 *pkcs12;
-	pass_info p(XCA_TITLE,
-		tr("Please enter the password to encrypt the PKCS#12 file"));
 
 	if (cert == NULL || key == NULL)
 		my_error(tr("No key or no Cert and no pkcs12"));
 
+	pass_info p(XCA_TITLE,
+		tr("Please enter the password to encrypt the key of certificate '%1' "
+		   "in the PKCS#12 file:\n%2")
+			.arg(cert->getIntName()).arg(nativeSeparator(file.fileName())));
+
 	if (PwDialogCore::execute(&p, &pass, true) != 1)
 		return;
 
@@ -148,11 +150,31 @@ void pki_pkcs12::writePKCS12(XFile &file, encAlgo &encAlgo) const
 		if (x && x != cert)
 			sk_X509_push(certstack, x->getCert());
 	}
-	int encAlgoNid = encAlgo.getEncAlgoNid();
+	int certAlgoNid, keyAlgoNid;
+	certAlgoNid = keyAlgoNid = encAlgo.getEncAlgoNid();
+
+	// The very ancient 40BitRC2_CBC algorithm at least can
+	// be combined with TripleDES_CBC for the keys.
+	if (keyAlgoNid == NID_pbe_WithSHA1And40BitRC2_CBC)
+		keyAlgoNid = NID_pbe_WithSHA1And3_Key_TripleDES_CBC;
+
+	EVP_PKEY *pkey = key->decryptKey();
+	for (const QString &line : key->getComment().split('\n')) {
+		QStringList kv = line.split(":");
+		qDebug() << line << kv;
+		if (kv.size() != 2 || kv[0] != "CSP")
+			continue;
+		QByteArray csp = kv[1].trimmed().toLatin1();
+		EVP_PKEY_add1_attr_by_NID(pkey, NID_ms_csp_name,
+			MBSTRING_ASC, (const unsigned char*)csp.constData(), csp.size());
+	}
+
 	pkcs12 = PKCS12_create(pass.data(), getIntName().toUtf8().data(),
-				key->decryptKey(), cert->getCert(), certstack,
-				encAlgoNid, encAlgoNid,
-				0, 0, 0);
+				pkey, cert->getCert(), certstack,
+				keyAlgoNid, certAlgoNid, 0, 0, 0);
+	pki_openssl_error();
+	EVP_PKEY_free(pkey);
+	Q_CHECK_PTR(pkcs12);
 
 	if (encAlgo.legacy())
 		PKCS12_set_mac(pkcs12, pass.data(), -1, NULL, 0, 1, EVP_sha1());
@@ -175,8 +197,10 @@ void pki_pkcs12::collect_properties(QMap<QString, QString> &prp) const
 
 // see https://www.rfc-editor.org/rfc/rfc8018 Appendix B.2 for possible encryption schemes
 const QList<int> encAlgo::all_encAlgos(
-	{ NID_pbe_WithSHA1And3_Key_TripleDES_CBC,
-	  NID_aes_256_cbc
+{
+	NID_pbe_WithSHA1And40BitRC2_CBC,
+	NID_pbe_WithSHA1And3_Key_TripleDES_CBC,
+	NID_aes_256_cbc
 });
 
 int encAlgo::default_encAlgo(NID_pbe_WithSHA1And3_Key_TripleDES_CBC);
@@ -197,6 +221,14 @@ QString encAlgo::name() const
 	return QString(encAlgo_nid == NID_undef ? "" : OBJ_nid2sn(encAlgo_nid));
 }
 
+QString encAlgo::displayName() const
+{
+	QString n = name();
+	if (legacy())
+		n += QString(" (%1)").arg(QObject::tr("insecure"));
+	return n;
+}
+
 int encAlgo::getEncAlgoNid() const
 {
 	return encAlgo_nid;
