@@ -83,6 +83,15 @@ x509v3ext &x509v3ext::create(int nid, const QString &et, X509V3_CTX *ctx)
 			if (new_san.size() > 0)
 				etext.replace(QString("DNS:copycn"), new_san.join(","));
 		}
+		if (nid == NID_subject_alt_name || nid == NID_issuer_alt_name || nid == NID_name_constraints) {
+			QStringList sl = etext.split(",");
+			QRegularExpression match("([a-z]+;)*UPN:");
+			for (int i=0; i<sl.size(); i++) {
+				QString s = sl[i].trimmed();
+				sl[i] = s.replace(match, "\\1otherName:msUPN;UTF8:");
+			}
+			etext = sl.join(",");
+		}
 		QByteArray ba = etext.toLocal8Bit();
 		ext = X509V3_EXT_conf_nid(NULL, ctx, nid, ba.data());
 	}
@@ -915,7 +924,7 @@ static bool nameConstraint(STACK_OF(GENERAL_SUBTREE) *trees,
 	return true;
 }
 
-bool x509v3ext::parse_nameConstraints(QString *, QString *adv) const
+bool x509v3ext::parse_nameConstraints(QString *single, QString *adv) const
 {
 	bool retval = true;
 	QString sect, ret;
@@ -938,11 +947,14 @@ bool x509v3ext::parse_nameConstraints(QString *, QString *adv) const
 	if (ret.size() > 0)
 		permEx << ret;
 
-	if (adv && retval &&permEx.size() > 0) {
+	if (retval && permEx.size() > 0) {
 		ret = permEx.join(", ");
-		qDebug("%s %d '%s'\n", __func__, retval, CCHAR(ret));
-		*adv = QString("%1=%2\n").arg(tag).
-			arg(parse_critical() +ret) + *adv + sect;
+		qDebug() << retval << ret;
+		if (single)
+			*single = ret;
+		else if (adv)
+			*adv = QString("%1=%2\n").arg(tag).
+				arg(parse_critical() +ret) + *adv + sect;
 	}
 	NAME_CONSTRAINTS_free(cons);
 	return retval;
@@ -1065,7 +1077,7 @@ void extList::setStack(const STACK_OF(X509_EXTENSION) *st, int start)
 	}
 }
 
-STACK_OF(X509_EXTENSION) *extList::getStack()
+STACK_OF(X509_EXTENSION) *extList::getStack() const
 {
 	STACK_OF(X509_EXTENSION) *sk = sk_X509_EXTENSION_new_null();
 	Q_CHECK_PTR(sk);
@@ -1074,7 +1086,7 @@ STACK_OF(X509_EXTENSION) *extList::getStack()
 	return sk;
 }
 
-bool extList::search(const QRegularExpression &pattern)
+bool extList::search(const QRegularExpression &pattern) const
 {
 	foreach(const x509v3ext &e, *this)
 		if (e.getValue().contains(pattern))
@@ -1113,7 +1125,7 @@ bool extList::delByNid(int nid)
 	return false;
 }
 
-int extList::idxByNid(int nid)
+int extList::idxByNid(int nid) const
 {
 	for(int i = 0; i< size(); i++) {
 		if (at(i).nid() == nid) {
