@@ -13,6 +13,9 @@
 
 #include "PwDialogMock.h"
 
+#include <QTest>
+#include <QtGlobal>
+
 class test_main: public QObject
 {
 	Q_OBJECT
@@ -32,6 +35,7 @@ class test_main: public QObject
 	void importPEM();
 	void exportFormat();
 	void revoke();
+	void testValidity();
 
   public:
 	template <class T> static T *findWindow(const QString &name)
@@ -45,8 +49,11 @@ class test_main: public QObject
 					ret = dest;
 				}
 			}
-			if (ret)
+			if (ret) {
+				if (!QTest::qWaitForWindowActive(ret))
+					return nullptr;
 				return ret;
+			}
 			QThread::msleep(50);
 		}
 		qWarning() << "Widget not found:" << name;
