@@ -23,35 +23,23 @@ const QList<QStringList> MainWindow::getTranslators() const
 {
 	return QList<QStringList> {
 	QStringList{ "", tr("System") },
-	QStringList{ "bg", tr("Bulgarian"),
-		"Svetoslav Slavkov", "contact", "sslavkov.eu" },
-	QStringList{ "zh_CN", tr("Chinese"),
-		"Xczh", "xczh.me", "foxmail.com" },
-	QStringList{ "hr", tr("Croatian"),
-		"Nevenko Bartolincic", "nevenko.bartolincic", "gmail.com" },
+	QStringList{ "bg", tr("Bulgarian"), "Svetoslav Slavkov", "contact", "sslavkov.eu" },
+	QStringList{ "zh_CN", tr("Chinese"), "Xczh", "xczh.me", "foxmail.com" },
+	QStringList{ "hr", tr("Croatian"), "Nevenko Bartolincic", "nevenko.bartolincic", "gmail.com" },
 	QStringList{ "nl", tr("Dutch"), "Guido Pennings" },
 	QStringList{ "en", tr("English") },
-	QStringList{ "fr", tr("French"),
-		"Patrick Monnerat", "patrick", "monnerat.net" },
-	QStringList{ "de", tr("German"),
-		"Christian Hohnstädt", "christian", "hohnstaedt.de" },
-	QStringList{ "id", tr("Indonesian"),
-		"Andika Triwidada", "andika", "gmail.com" },
-	QStringList{ "it", tr("Italian"),
-		"Paolo Basenghi", "paul69", "libero.it" },
-	QStringList{ "ja", tr("Japanese"),
-		"D2N", "gritty.hat3143", "mx.d2-networks.jp" },
-	QStringList{ "fa", tr("Persian"),
-		"Erfan Esmayili Barzi", "erfankam", "gmail.com" },
-	QStringList{ "pl", tr("Polish"),
-		"Jacek Tyborowski", "jacek", "tyborowski.pl" },
-	QStringList{ "pt_BR", tr("Portuguese in Brazil"),
-		"Ulisses Guedes", "uli1958", "hotmail.com" },
+	QStringList{ "fr", tr("French"), "Patrick Monnerat", "patrick", "monnerat.net" },
+	QStringList{ "de", tr("German"), "Christian Hohnstädt", "christian", "hohnstaedt.de" },
+	QStringList{ "id", tr("Indonesian"), "Andika Triwidada", "andika", "gmail.com" },
+	QStringList{ "it", tr("Italian"), "Paolo Basenghi", "paul69", "libero.it" },
+	QStringList{ "ja", tr("Japanese"), "D2N", "gritty.hat3143", "mx.d2-networks.jp" },
+	QStringList{ "fa", tr("Persian"), "Erfan Esmayili Barzi", "erfankam", "gmail.com" },
+	QStringList{ "ko", tr("Korean"), "Kim Dongil", "icoicoya", "naver.com" },
+	QStringList{ "pl", tr("Polish"), "Jacek Tyborowski", "jacek", "tyborowski.pl" },
+	QStringList{ "pt_BR", tr("Portuguese in Brazil"), "Ulisses Guedes", "uli1958", "hotmail.com" },
 	QStringList{ "ru", tr("Russian") },
-	QStringList{ "sk", tr("Slovak"),
-		"Slavko", "linux", "slavino.sk" },
-	QStringList{ "es", tr("Spanish"),
-		"Miguel Romera", "mrmsoftdonation", "gmail.com" },
+	QStringList{ "sk", tr("Slovak"), "Slavko", "linux", "slavino.sk" },
+	QStringList{ "es", tr("Spanish"), "Miguel Romera", "mrmsoftdonation", "gmail.com" },
 	QStringList{ "tr", tr("Turkish") },
 	};
 };
@@ -106,7 +94,7 @@ void MainWindow::about()
 	"<p>Copyright 2001 - 2024 by Christian Hohnstädt\n"
 	"<p>Version: %3<p>%1" /* commithash, OpenSSL & Qt Version */
 	"<p><a href=\"https://hohnstaedt.de/xca\">https://hohnstaedt.de/xca</a>"
-	"<p>Entropy strength: %2"
+	"<p>OpenSSL legacy provider%2 loaded"
 	"<p><table border=\"0\">"
 	"<tr><td>Installation path:</td><td>%4</td></tr>"
 	"<tr><td>User settings path:</td><td>%5</td></tr>"
@@ -120,7 +108,7 @@ void MainWindow::about()
 	"</table><hr><center><u><b>Maintained Translations</b></u></center>"
 	"<p><table><tr>%8</tr></table>")
 			.arg(version)
-			.arg(Entropy::strength())
+			.arg(legacy_loaded ? "" : " not")
 			.arg(version_str(true))
 			.arg(nativeSeparator(QCoreApplication::applicationDirPath()))
 			.arg(nativeSeparator(getUserSettingsDir()))
