@@ -36,6 +36,7 @@
 #include "lib/db_temp.h"
 #include "lib/oid.h"
 #include "lib/func.h"
+#include "lib/pki_evp.h"
 
 void NewX509::setupExplicitDN(NIDlist my_dn_nid = NIDlist())
 {
@@ -134,6 +135,8 @@ NewX509::NewX509(QWidget *w) : XcaDetail(w)
 	connect(extDNlist->itemDelegateForColumn(1),
 		SIGNAL(setupLineEdit(const QString &, QLineEdit *)),
 		       this, SLOT(setupExtDNwidget(const QString &, QLineEdit *)));
+	connect(nameCons, SIGNAL(textChanged(const QString &)),
+	        this, SLOT(checkNameConstraints(const QString &)));
 	connect(subAltName, SIGNAL(textChanged(const QString &)),
 	        this, SLOT(checkSubAltName(const QString &)));
 	connect(issAltName, SIGNAL(textChanged(const QString &)),
@@ -210,6 +213,7 @@ NewX509::NewX509(QWidget *w) : XcaDetail(w)
 	basicPath->setValidator(new QIntValidator(0, 1000, this));
 
 	QMap<int, QWidget*> nidWidget;
+	nidWidget[NID_name_constraints] = nameConsLbl;
 	nidWidget[NID_subject_alt_name] = sanLbl;
 	nidWidget[NID_issuer_alt_name] = ianLbl;
 	nidWidget[NID_crl_distribution_points] = crldpLbl;
@@ -277,6 +281,7 @@ NewX509::NewX509(QWidget *w) : XcaDetail(w)
 
 	// Setup widget <-> Template mapping
 #define MAP_LE(name) templateLineEdits[#name] = name;
+	MAP_LE(nameCons);
 	MAP_LE(subAltName);
 	MAP_LE(issAltName);
 	MAP_LE(crlDist);
@@ -365,7 +370,7 @@ void NewX509::setReqAttributes(pki_x509req *req)
 }
 
 /* Initialize dialog for Template creation */
-void NewX509::setTemp(pki_temp *temp)
+void NewX509::setTemp(pki_temp *temp, bool create)
 {
 	description->setText(temp->getIntName());
 	capt->setText(tr("Edit XCA template"));
@@ -376,17 +381,8 @@ void NewX509::setTemp(pki_temp *temp)
 	pt = tmpl;
 	fromTemplate(temp);
 	comment->setPlainText(temp->getComment());
-	connect_pki(temp);
-}
-
-void NewX509::disableAllButNameComment()
-{
-	tab_0->setEnabled(false);
-	tab_2->setEnabled(false);
-	tab_3->setEnabled(false);
-	tab_4->setEnabled(false);
-	distNameBox->setEnabled(false);
-	privKeyBox->setEnabled(false);
+	if (!create)
+		connect_pki(temp);
 }
 
 /* Initialize dialog for Certificate creation */
@@ -537,6 +533,7 @@ void NewX509::extensionsFromTemplate(pki_temp *temp)
 	QMapIterator<QString, QLineEdit*> l(templateLineEdits);
 	while (l.hasNext()) {
 		l.next();
+		qDebug() << "APPLY LineEdits" << l.key() << temp->getSetting(l.key());
 		l.value()->setText(temp->getSetting(l.key()));
 	}
 	QMapIterator<QString, QCheckBox*> i(templateCheckBoxes);
@@ -560,8 +557,17 @@ void NewX509::fromTemplate(pki_temp *temp)
 	extensionsFromTemplate(temp);
 }
 
+void NewX509::updateNameComment()
+{
+	// If we display a template, import all changes to the template
+	pki_temp *temp = dynamic_cast<pki_temp*>(pki);
+	toTemplate(temp);
+}
+
 void NewX509::toTemplate(pki_temp *temp)
 {
+	if (!temp)
+		return;
 	temp->setIntName(description->text());
 	temp->setSubject(getX509name());
 
@@ -868,7 +874,7 @@ void NewX509::setX509name(const x509name &n)
 		ne.edit->setText("");
 	}
 
-	if (Settings["adapt_explicit_subject"]) {
+	if (Settings["adapt_explicit_subj"]) {
 		NIDlist mydn;
 		for (int i=0; i< n.entryCount(); i++)
 			mydn << n.nid(i);
@@ -928,6 +934,8 @@ void NewX509::setupTmpCtx()
 		ctx_cert->setIssuer(ctx_cert->getSubject());
 	}
 	ctx_cert->setSerial(serial);
+	ctx_cert->setNotBefore(notBefore->getDate());
+	ctx_cert->setNotAfter(notAfter->getDate());
 	initCtx(ctx_cert, signcert, req);
 }
 
@@ -963,6 +971,9 @@ void NewX509::checkIcon(const QString &text, int nid, QLabel *img)
 	setupTmpCtx();
 	ign_openssl_error();
 	switch (nid) {
+	case NID_name_constraints:
+		ext = getNameConstraints();
+		break;
 	case NID_subject_alt_name:
 		ext = getSubAltName();
 		break;
@@ -979,6 +990,11 @@ void NewX509::checkIcon(const QString &text, int nid, QLabel *img)
 	img->setPixmap(ext.isValid() ? QPixmap(":doneIco") : QPixmap(":warnIco"));
 }
 
+void NewX509::checkNameConstraints(const QString & text)
+{
+	checkIcon(text, NID_name_constraints, nameConsIco);
+}
+
 void NewX509::checkSubAltName(const QString & text)
 {
 	checkIcon(text, NID_subject_alt_name, subAltIco);
@@ -999,15 +1015,15 @@ void NewX509::checkAuthInfAcc(const QString & text)
 	checkIcon(text, NID_info_access, authInfAccIco);
 }
 
-int NewX509::do_validateExtensions()
+enum NewX509::extension_error NewX509::do_validateExtensions()
 {
 	QString result;
-	int ret = 0;
+	extension_error ret;
 
 	if (!nconf_data->isReadOnly()) {
 		v3ext_backup = nconf_data->toPlainText();
 	}
-	ret = validateExtensions(v3ext_backup, result);
+	ret = validateExtensions(result);
 	nconf_data->document()->setHtml(result);
 	nconf_data->setReadOnly(true);
 	adv_validate->setText(tr("Edit"));
@@ -1023,14 +1039,14 @@ void NewX509::undo_validateExtensions()
 	adv_validate->setText(tr("Validate"));
 }
 
-int NewX509::validateExtensions(QString nconf, QString &result)
+enum NewX509::extension_error NewX509::validateExtensions(QString &result)
 {
-	int ret = 0, ext_count = 0;
+	enum extension_error ee = ee_none;
 	QStringList errors;
-	extList el, req_el;
+	extList el, el_all, req_el;
 	ign_openssl_error();
 	setupTmpCtx();
-	(void)nconf;
+
 	try {
 		el = getGuiExt();
 		if (!Settings["disable_netscape"])
@@ -1040,19 +1056,20 @@ int NewX509::validateExtensions(QString nconf, QString &result)
 		errors += err.getString();
 		el.clear();
 	}
-	ext_count += el.size();
 	if (el.size() > 0) {
 		result += "<h2><center>";
 		result += tr("Other Tabs") + "</center></h2><p>\n";
 		result += el.getHtml("<br>");
 	}
+	setupTmpCtx();
+	el_all += el;
 	try {
 		el = getAdvanced();
 	} catch (errorEx &err) {
 		errors += err.getString();
 		el.clear();
 	}
-	ext_count += el.size();
+	el_all += el;
 	if (el.size() > 0) {
 		if (!result.isEmpty())
 			result += "\n<hr>\n";
@@ -1067,9 +1084,10 @@ int NewX509::validateExtensions(QString nconf, QString &result)
 		result += tr("Errors") + "</center></h2><p><ul><li>\n";
 		result += errors.join("</li><li>\n");
 		result += "</li></ul>";
-		ret = 1;
+		ee = ee_invaldup;
 	}
 	el.clear();
+	setupTmpCtx();
 	if (fromReqCB->isChecked() && copyReqExtCB->isChecked()) {
 		req_el = getSelectedReq()->getV3ext();
 		for (int i=0; i<req_el.count(); i++) {
@@ -1077,7 +1095,7 @@ int NewX509::validateExtensions(QString nconf, QString &result)
 				el += req_el[i];
 		}
 	}
-	ext_count += el.size();
+	el_all += el;
 	if (el.size() > 0) {
 		if (!result.isEmpty())
 			result += "\n<hr>\n";
@@ -1085,12 +1103,14 @@ int NewX509::validateExtensions(QString nconf, QString &result)
 		result += tr("From PKCS#10 request") +"</center></h2><p>\n";
 		result += el.getHtml("<br>");
 	}
-	el = getExtDuplicates();
+	el = getExtDuplicates(el_all);
 	if (el.size() > 0) {
 		QString errtxt;
-		ret = 1;
-		errtxt = "<h2><center><font color=\"red\">Error:</font>"
-			"duplicate extensions:</center></h2><p><ul>\n";
+		ee = ee_invaldup;
+		errtxt = QString("<h2><center>"
+					"<font color=\"red\">%1:</font> %2:"
+				"</center></h2><p><ul>\n")
+			.arg(tr("Error")).arg(tr("duplicate extensions"));
 		for(int i = 0; i< el.size(); i++) {
 			errtxt += "<li>" +el[i].getObject() +"</li>\n";
 		}
@@ -1098,36 +1118,49 @@ int NewX509::validateExtensions(QString nconf, QString &result)
 		result = errtxt + result;
 	}
 	QString lineext;
+	if (!nameCons->text().isEmpty() && !getNameConstraints().isValid())
+		lineext += tr("The Name Constraints are invalid") + "<br>\n";
 	if (!subAltName->text().isEmpty() && !getSubAltName().isValid())
-		lineext += "The Subject Alternative Name is invalid<br>\n";
+		lineext += tr("The Subject Alternative Name is invalid") + "<br>\n";
 	if (!issAltName->text().isEmpty() && !getIssAltName().isValid())
-		lineext += "The Issuer Alternative Name is invalid<br>\n";
+		lineext += tr("The Issuer Alternative Name is invalid") + "<br>\n";
 	if (!crlDist->text().isEmpty() && !getCrlDist().isValid())
-		lineext += "The CRL Distribution Point is invalid<br>\n";
+		lineext += tr("The CRL Distribution Point is invalid") + "<br>\n";
 	if (!authInfAcc->text().isEmpty() && !getAuthInfAcc().isValid())
-		lineext += "The Authority Information Access is invalid<br>\n";
+		lineext += tr("The Authority Information Access is invalid") + "<br>\n";
 	if (!lineext.isEmpty()) {
 		if (!result.isEmpty())
 			result += "\n<hr>\n";
 		result += lineext;
-		ret = 3;
+		ee = ee_inval;
 	}
-	if (ret == 0 && ext_count == 0 && pt == x509)
-		ret = 2;
+	if (ee == ee_none && el_all.size() == 0 && pt == x509)
+		ee = ee_empty;
 
 	ign_openssl_error();
-	return ret;
+	return ee;
+}
+
+void NewX509::on_editNameCons_clicked()
+{
+	QStringList permut;
+	for (const QString &group : QStringList { "permitted", "excluded" }) {
+		for(const QString &type : QStringList { "URI", "email", "RID", "DNS", "IP", "UPN", "othername" }) {
+			permut << QString("%1;%2").arg(group).arg(type);
+		}
+	}
+	editV3ext(nameCons, permut.join(","), NID_name_constraints);
 }
 
 void NewX509::on_editSubAlt_clicked()
 {
-	QString s = "URI,email,RID,DNS,IP,otherName";
+	QString s = "URI,email,RID,DNS,IP,UPN,otherName";
 	editV3ext(subAltName, s, NID_subject_alt_name);
 }
 
 void NewX509::on_editIssAlt_clicked()
 {
-	QString s = "URI,email,RID,DNS,IP,otherName,issuer";
+	QString s = "URI,email,RID,DNS,IP,UPN,otherName,issuer";
 	editV3ext(issAltName, s, NID_issuer_alt_name);
 }
 
@@ -1392,22 +1425,24 @@ void NewX509::accept()
 				break;
 		}
 	}
-	int r = do_validateExtensions();
-	if (r) {
+	enum extension_error ee = do_validateExtensions();
+	if (ee != ee_none) {
 		QString text;
-		switch (r) {
-		case 1:
+		switch (ee) {
+		case ee_invaldup:
 			text = tr("The certificate contains invalid or duplicate extensions. Check the validation on the advanced tab.");
 			gotoTab(5);
 			break;
-		case 2:
+		case ee_empty:
 			text = tr("The certificate contains no extensions. You may apply the extensions of one of the templates to define the purpose of the certificate.");
 			gotoTab(0);
 			break;
-		case 3:
+		case ee_inval:
 			text = tr("The certificate contains invalid extensions.");
 			gotoTab(2);
 			break;
+		case ee_none:
+			break;
 		}
 		xcaWarningBox msg(this, text);
 		msg.addButton(QMessageBox::Ok, tr("Edit extensions"));
@@ -1445,6 +1480,40 @@ void NewX509::accept()
 				break;
 		}
 	}
+	if (foreignSignRB->isChecked()) {
+		setupTmpCtx();
+		// Update SAN and BC of ctx_cert
+		getBasicConstraints();
+		getSubAltName();
+		for (pki_x509 *crt = getSelectedSigner(), *oldcrt = nullptr;
+			crt && crt != oldcrt;
+			oldcrt = crt, crt = crt->getSigner())
+		{
+			int rc = ctx_cert->name_constraint_check(crt);
+			qDebug() << ctx_cert->getIntName() << "Issuer"
+			         << crt->getIntName()<< get_ossl_verify_error(rc);
+			if (rc == X509_V_OK)
+				continue;
+			gotoTab(2);
+			xcaWarningBox msg(this, tr("A name constraint of the issuer '%1' is violated: %2")
+				.arg(crt->getIntName()).arg(get_ossl_verify_error(rc)));
+			msg.setInformativeText(crt->getExtByNid(NID_name_constraints).getValue());
+			msg.addButton(QMessageBox::Ok, tr("Edit extensions"));
+			msg.addButton(QMessageBox::Close, tr("Abort rollout"));
+			msg.addButton(QMessageBox::Apply, tr("Continue rollout"));
+			switch (msg.exec())
+			{
+				case QMessageBox::Ok:
+				case QMessageBox::Cancel:
+					return;
+				case QMessageBox::Close:
+					reject();
+					return;
+				case QMessageBox::Apply:
+					break;
+			}
+		}
+	}
 	XcaDetail::accept();
 }
 
@@ -1454,7 +1523,6 @@ void NewX509::showTemp(QWidget *parent, pki_temp *x)
 		return;
 	NewX509 *dlg = new NewX509(parent);
 	dlg->setTemp(x);
-	dlg->disableAllButNameComment();
 	dlg->exec();
 	delete dlg;
 }
