@@ -24,11 +24,13 @@ class ReqTreeView: public X509SuperTreeView
 	ReqTreeView(QWidget *parent) : X509SuperTreeView(parent) { }
 	void fillContextMenu(QMenu *menu, QMenu *subExport,
 			const QModelIndex &index, QModelIndexList indexes);
+	ExportDialog *exportDialog(const QModelIndexList &indexes);
 
     public slots:
 	void toRequest();
 	void signReq();
 	void markSigned();
 	void unmarkSigned();
+	void load();
 };
 #endif
