@@ -16,7 +16,7 @@
 #include <QFileDialog>
 #include <QMenu>
 
-void X509SuperTreeView::fillContextMenu(QMenu *menu, QMenu *subExport,
+void X509SuperTreeView::fillContextMenu(QMenu *menu, QMenu *,
 		const QModelIndex &index, QModelIndexList indexes)
 {
 	pki_x509super *x = dynamic_cast<pki_x509super*>(
@@ -25,7 +25,6 @@ void X509SuperTreeView::fillContextMenu(QMenu *menu, QMenu *subExport,
 	if (indexes.size() != 1 || !x)
 		return;
 
-	subExport->addAction(tr("OpenSSL config"), this, SLOT(toOpenssl()));
 	transform = menu->addMenu(tr("Transform"));
 	transform->addAction(tr("Template"), this, SLOT(toTemplate()));
 	transform->addAction(tr("Public key"), this,
@@ -48,26 +47,6 @@ void X509SuperTreeView::toTemplate()
 		x509super()->toTemplate(idx);
 }
 
-void X509SuperTreeView::toOpenssl()
-{
-	QModelIndex idx = currentIndex();
-
-	if (!idx.isValid() || !basemodel)
-		return;
-
-	pki_x509super *pki = db_base::fromIndex<pki_x509super>(idx);
-	QString fn = Settings["workingdir"] + pki->getUnderlinedName() + ".conf";
-	QString fname = QFileDialog::getSaveFileName(NULL,
-		tr("Save as OpenSSL config"),   fn,
-		tr("Config files ( *.conf *.cnf);; All files ( * )"));
-	if (fname.isEmpty())
-		return;
-
-	update_workingdir(fname);
-	pki->opensslConf(fname);
-}
-
-
 void X509SuperTreeView::showPki(pki_base *pki)
 {
 	pki_x509super *x = dynamic_cast<pki_x509super *>(pki);
